@@ -21,22 +21,28 @@ test_that("names<-()", {
   scoped_lifecycle_warnings()
 
   if (!is_rstudio()) {
-    expect_warning(set_tbl_names(NULL), class = "lifecycle_error_deprecated")
+    expect_warning(
+      set_tbl_names(NULL),
+      class = "lifecycle_warning_deprecated"
+    )
   }
 
-  expect_warning(
-    expect_identical(set_tbl_names("c"), new_tbl("c", NA_character_)),
-    class = "lifecycle_error_deprecated"
+  # Two warnings, require testthat > 2.3.2:
+  suppressWarnings(
+    expect_warning(
+      expect_identical(set_tbl_names("c"), new_tbl("c", NA_character_)),
+      class = "lifecycle_warning_deprecated"
+    )
   )
 
   expect_warning(
     expect_identical(set_tbl_names(letters[3:5]), new_tbl("c", "d")),
-    class = "lifecycle_error_deprecated"
+    class = "lifecycle_warning_deprecated"
   )
 
   expect_warning(
     expect_identical(set_tbl_names(3:4), new_tbl(3:4)),
-    class = "lifecycle_error_deprecated"
+    class = "lifecycle_warning_deprecated"
   )
 })
 
