@@ -5,7 +5,7 @@ test_that("error class", {
 })
 
 test_that("aborting with class", {
-  expect_error(cnd_signal(error_enframe_value_null()), class = tibble_error_class("enframe_value_null"))
+  expect_error(cnd_signal(error_enframe_value_null()), class = tibble_error_class("enframe_value_null")[[1]])
 })
 
 verify_output("msg.txt", {
@@ -81,21 +81,11 @@ verify_output("msg.txt", {
   error_subset_columns_non_missing_only()
   error_assign_columns_non_missing_only()
 
-  error_new_columns_at_end_only(5, 7:8)
-  error_new_columns_at_end_only(5, 7)
-  error_new_columns_at_end_only(1, 7:8)
-  error_new_columns_at_end_only(1, 7)
-
   error_duplicate_column_subscript_for_assignment(c(1, 1))
   error_duplicate_column_subscript_for_assignment(c(1, 1, 2, 2))
 
   error_assign_rows_non_na_only()
 
-  error_new_rows_at_end_only(5, 7:8)
-  error_new_rows_at_end_only(5, 7)
-  error_new_rows_at_end_only(1, 7:8)
-  error_new_rows_at_end_only(1, 7)
-
   error_duplicate_row_subscript_for_assignment(c(1, 1))
   error_duplicate_row_subscript_for_assignment(c(1, 1, 2, 2))
 
